---
title: <span class="badge object-type-scalar"></span> Seconds
---
# <span class="badge object-type-scalar"></span> Seconds

Time: seconds (s)

## Definition

```python
# Time: seconds (s)
Seconds: typing.Literal["s"] = "s"
```
